Share and Enjoy
===============

``covertile.cycle2`` would not have been possible without the contribution of the following people:

- André Nogueira
- Daniel Jowett
- Héctor Velarde
- Fred van Dijk

You can find an updated list of package contributors on `GitHub`_.

.. _`GitHub`: https://github.com/collective/covertile.cycle2/contributors
